from setuptools import setup

setup(name='dist_proba',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['dist_proba'],
      author= 'Christophe Berset',
      author_email = 'bersetchristophe@gmail.com',
      zip_safe=False)
